import { defineComponent, h, ref } from 'vue';
export default defineComponent({
    name: 'CodeGroup',
    setup(_, { slots }) {
        // index of current active item
        const activeIndex = ref(-1);
        return () => {
            // NOTICE: here we put the `slots.default()` inside the render function to make
            // the slots reactive, otherwise the slot content won't be changed once the
            // `setup()` function of current component is called
            var _a;
            // get children code-group-item
            const items = (((_a = slots.default) === null || _a === void 0 ? void 0 : _a.call(slots)) || [])
                .filter((vnode) => vnode.type.name === 'CodeGroupItem')
                .map((vnode) => {
                if (vnode.props === null) {
                    vnode.props = {};
                }
                return vnode;
            });
            // do not render anything if there is no code-group-item
            if (items.length === 0) {
                return null;
            }
            if (activeIndex.value === -1) {
                // initial state
                // find the index of the code-group-item with `active` props
                activeIndex.value = items.findIndex((vnode) => vnode.props.active === '' || vnode.props.active === true);
                // if there is no `active` props on code-group-item, set the first item active
                if (activeIndex.value === -1) {
                    activeIndex.value = 0;
                }
            }
            else {
                // re-render triggered by modifying `activeIndex` ref
                // set the active item
                items.forEach((vnode, i) => {
                    vnode.props.active = i === activeIndex.value;
                });
            }
            return h('div', { class: 'code-group' }, [
                h('div', { class: 'code-group__nav' }, h('ul', { class: 'code-group__ul' }, items.map((vnode, i) => h('li', { class: 'code-group__li' }, h('button', {
                    class: `code-group__nav-tab${i === activeIndex.value
                        ? ' code-group__nav-tab-active'
                        : ''}`,
                    onClick: () => (activeIndex.value = i),
                }, vnode.props.title))))),
                items,
            ]);
        };
    },
});
